<?php

namespace Buyesrfolio\LeadMeeting\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Buyesrfolio\LeadMeeting\Http\Requests\LeadMeetingRequest;
use Buyesrfolio\LeadMeeting\Interfaces\LeadMeetingRepositoryInterface;
use Buyesrfolio\LeadMeeting\Models\LeadMeeting;
use Buyesrfolio\LeadMeeting\Forms\LeadMeeting as Form;

/**
 * APIController  class for lead_meeting.
 */
class LeadMeetingAPIController extends BaseController
{

    /**
     * Initialize lead_meeting resource controller.
     *
     * @param type LeadMeetingRepositoryInterface $lead_meeting
     *
     * @return null
     */
    public function __construct(LeadMeetingRepositoryInterface $lead_meeting)
    {
        parent::__construct();
        $this->repository = $lead_meeting;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Buyesrfolio\LeadMeeting\Repositories\Criteria\LeadMeetingResourceCriteria::class);
    }

    /**
     * Display a list of lead_meeting.
     *
     * @return Response
     */
    public function index(LeadMeetingRequest $request)
    {
        return $this->repository
            ->setPresenter(\Buyesrfolio\LeadMeeting\Repositories\Presenter\LeadMeetingPresenter::class)
            ->paginate();
    }

    /**
     * Display lead_meeting.
     *
     * @param Request $request
     * @param Model   $lead_meeting
     *
     * @return Response
     */
    public function show(LeadMeetingRequest $request, LeadMeeting $lead_meeting)
    {
        return $lead_meeting->setPresenter(\Buyesrfolio\LeadMeeting\Repositories\Presenter\LeadMeetingListPresenter::class);
        ;
    }

    /**
     * Create new lead_meeting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LeadMeetingRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('lead_meeting::lead_meeting.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('lead_meeting/lead_meeting/' . $lead_meeting->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('lead_meeting/lead_meeting');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the lead_meeting.
     *
     * @param Request $request
     * @param Model   $lead_meeting
     *
     * @return Response
     */
    public function update(LeadMeetingRequest $request, LeadMeeting $lead_meeting)
    {
        try {
            $data = $request->all();

            $lead_meeting->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('lead_meeting::lead_meeting.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('lead_meeting/lead_meeting/' . $lead_meeting->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('lead_meeting/lead_meeting/' . $lead_meeting->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the lead_meeting.
     *
     * @param Model   $lead_meeting
     *
     * @return Response
     */
    public function destroy(LeadMeetingRequest $request, LeadMeeting $lead_meeting)
    {
        try {
            $lead_meeting->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('lead_meeting::lead_meeting.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('lead_meeting/lead_meeting/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('lead_meeting/lead_meeting/' . $lead_meeting->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
