<?php

namespace Buyesrfolio\LeadMeeting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Buyesrfolio\LeadMeeting\Models\LeadMeeting;

class LeadMeetingPolicy
{

    /**
     * Determine if the given user can view the lead_meeting.
     *
     * @param UserPolicy $user
     * @param LeadMeeting $lead_meeting
     *
     * @return bool
     */
    public function view(UserPolicy $user, LeadMeeting $lead_meeting)
    {
        if ($user->canDo('lead_meeting.lead_meeting.view') && $user->isAdmin()) {
            return true;
        }

        return $lead_meeting->user_id == user_id() && $lead_meeting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a lead_meeting.
     *
     * @param UserPolicy $user
     * @param LeadMeeting $lead_meeting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('lead_meeting.lead_meeting.create');
    }

    /**
     * Determine if the given user can update the given lead_meeting.
     *
     * @param UserPolicy $user
     * @param LeadMeeting $lead_meeting
     *
     * @return bool
     */
    public function update(UserPolicy $user, LeadMeeting $lead_meeting)
    {
        if ($user->canDo('lead_meeting.lead_meeting.edit') && $user->isAdmin()) {
            return true;
        }

        return $lead_meeting->user_id == user_id() && $lead_meeting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given lead_meeting.
     *
     * @param UserPolicy $user
     * @param LeadMeeting $lead_meeting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, LeadMeeting $lead_meeting)
    {
        return $lead_meeting->user_id == user_id() && $lead_meeting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given lead_meeting.
     *
     * @param UserPolicy $user
     * @param LeadMeeting $lead_meeting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, LeadMeeting $lead_meeting)
    {
        if ($user->canDo('lead_meeting.lead_meeting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lead_meeting.
     *
     * @param UserPolicy $user
     * @param LeadMeeting $lead_meeting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, LeadMeeting $lead_meeting)
    {
        if ($user->canDo('lead_meeting.lead_meeting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
